==> hoogle-5.0.18.4-79-x86_64.pkg.tar.zst: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-HC6PHBMM92bCFImVCxKx2D
key:                  hoogle-5.0.18.4-HC6PHBMM92bCFImVCxKx2D
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  d8d04cdbf62da50ed2840a4dc34944cb
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-HC6PHBMM92bCFImVCxKx2D
include-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT base-4.16.4.0 binary-0.8.9.0
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    conduit-1.3.6.1-EY3LytHQczX5mIGEpu5xiY
    conduit-extra-1.3.6-7mikRIbPiDe1GLkC5pwuGa containers-0.6.5.1
    crypton-connection-0.3.2-CRnF9J89Sj4Y0mwjk0diN deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-EWGdPHvQLeb5EiMAbHqdrp
    filepath-1.4.2.2 foundation-0.0.30-HGERhRs5JCDILoHDx95jS
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    http-conduit-2.3.9.1-55D1Kv3HLmSF9w0pn7kxkl
    http-types-0.12.4-EUtXhu021ZKEzVhlnug85Q
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-8NPyW1ADj4F86662xVeloZ
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    process-extras-0.7.4-8X3IYqjKgd8FFQR5nWxAg
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    storable-tuple-0.1-3o4Z0zZ6Qoz9j8WhJvKENp
    tar-0.5.1.1-BWSSFc6YC8c7wv111YuSYr template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    uniplate-1.6.13-13N6qNM0ncy2qFDgjyRb6W
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    wai-3.2.4-Jk3PC0rxUdX8PQLGr3R9HH
    wai-logger-2.5.0-FqaGZszjlxa1VBLqLePlrc
    warp-3.3.30-3i5ueGuwVMS35eRYRRpIDM
    warp-tls-3.4.9-LqZKNJ98BWJ9fwxcFuAQAo
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.18.4-80-x86_64.pkg.tar.zst: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-7LsKtf3aWXf7YEKkAcqk4j
key:                  hoogle-5.0.18.4-7LsKtf3aWXf7YEKkAcqk4j
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  d623c7d7b7709d3cf891c0316317ae10
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-7LsKtf3aWXf7YEKkAcqk4j
include-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-LOsc8VZqmR4FTSS4ItJTX9 base-4.16.4.0 binary-0.8.9.0
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    conduit-1.3.6.1-HO5zjhEeUfE6auWqLrKi5s
    conduit-extra-1.3.6-8xA72F23Yd029oLw2H0Gnt containers-0.6.5.1
    crypton-connection-0.3.2-CRnF9J89Sj4Y0mwjk0diN deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-9QXTGuykCno1FsMdBZzFkU
    filepath-1.4.2.2 foundation-0.0.30-HGERhRs5JCDILoHDx95jS
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    http-conduit-2.3.9.1-zkdLEUpoDSDtmOWQ3syim
    http-types-0.12.4-73sm5RQDELf14ScpiP2ZCD
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-GA6hZnKqvESFNt6ZFCf41
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    process-extras-0.7.4-8X3IYqjKgd8FFQR5nWxAg
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    storable-tuple-0.1-3o4Z0zZ6Qoz9j8WhJvKENp
    tar-0.5.1.1-BWSSFc6YC8c7wv111YuSYr template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    uniplate-1.6.13-13N6qNM0ncy2qFDgjyRb6W
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    wai-3.2.4-I5texftKO2H3qZmxfNORCg
    wai-logger-2.5.0-FbWkS7tufNb8ATkXhsiFa4
    warp-3.3.30-2Qet8aVmhopGeEkKHAf5ec
    warp-tls-3.4.9-6embkohTxgwJSibA5croQM
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
